@@ -15,16 +15,21 @@ class DouyutvVideo(Extractor):
 
     def prepare(self):
         info = MediaInfo(self.name)
-        pid = match1(self.url, 'show/(.*)')
-        if 'vmobile' in self.url:
-            self.url = 'https://v.douyu.com/show/' + pid
+
+        if self.vid is None:
+            self.vid = match1(self.url, 'show/(\w+)')
+        assert self.vid, "can't find video!!!"
+
+        if self.url is None or 'vmobile' in self.url:
+            self.url = 'https://v.douyu.com/show/' + self.vid
 
         html = get_content(self.url)
         info.title = match1(html, 'title>(.+?)_斗鱼视频 - 最6的弹幕视频网站<')
-        self.vid = match1(html, '"point_id":\s?(\d+)')
+        self.vid, vid = match1(html, '"point_id":\s?(\d+)'), self.vid
+        assert self.vid, "can't find video!!!"
 
         js_enc = get_h5enc(html, self.vid)
-        params = {'vid': pid}
+        params = {'vid': vid}
         ub98484234(js_enc, self, params)
 
         add_header('Referer', self.url)
